@@ -30,7 +30,7 @@ class ForgeHgApp(RepositoryApp):
     """
     ordinal=3
     forkable=True
-    default_branch_name='ref/default'
+    default_branch_name='default'
 
     def __init__(self, project, config):
         super(ForgeHgApp, self).__init__(project, config)
