@@ -331,7 +331,7 @@ class HgImplementation(M.RepositoryImplementation):
     def commits_count(self, path=None, rev=None):
         return sum(1 for _ in self.commits(path=path, rev=rev))
 
-    def tarball(self, commit):
+    def tarball(self, commit, path=None):
         if not os.path.exists(self._repo.tarball_path):
             os.makedirs(self._repo.tarball_path)
         archive_name = self._repo.tarball_filename(commit)
